==> rbac-import-2.2.1.11-Release-sources.jar: com/bizunited/platform/rbac/vo/RoleImportVo.java <==
package com.bizunited.platform.rbac.vo;

import com.bizunited.platform.kuiper.starter.common.excel.NebulaExcelColumn;
import com.bizunited.platform.kuiper.starter.common.excel.NebulaExcelImport;
import java.io.Serializable;

/**
 * 角色导入对象模型
 * @Author: chenrong
 * @Date: 2020/10/28 9:24
 */
@NebulaExcelImport(startRow = 2)
public class RoleImportVo implements Serializable {

  private static final long serialVersionUID = -8169850517983676178L;

  /** 角色编码 **/
  @NebulaExcelColumn(order = 0)
  private String roleCode;

  /** 角色名称 **/
  @NebulaExcelColumn(order = 1)
  private String roleName;

  /** 角色类型 **/
  @NebulaExcelColumn(order = 2)
  private String roleType;

  /** 角色状态 **/
  @NebulaExcelColumn(order = 3)
  private String tstatus;

  /** 是否系统角色 **/
  @NebulaExcelColumn(order = 4)
  private String isDeny;

  /** 父级角色编码 **/
  @NebulaExcelColumn(order = 5)
  private String parentCode;

  /** 角色备注 **/
  @NebulaExcelColumn(order = 6)
  private String comment;

  public String getRoleCode() {
    return roleCode;
  }

  public void setRoleCode(String roleCode) {
    this.roleCode = roleCode;
  }

  public String getRoleName() {
    return roleName;
  }

  public void setRoleName(String roleName) {
    this.roleName = roleName;
  }

  public String getRoleType() {
    return roleType;
  }

  public void setRoleType(String roleType) {
    this.roleType = roleType;
  }

  public String getTstatus() {
    return tstatus;
  }

  public void setTstatus(String tstatus) {
    this.tstatus = tstatus;
  }

  public String getIsDeny() {
    return isDeny;
  }

  public void setIsDeny(String isDeny) {
    this.isDeny = isDeny;
  }

  public String getParentCode() {
    return parentCode;
  }

  public void setParentCode(String parentCode) {
    this.parentCode = parentCode;
  }

  public String getComment() {
    return comment;
  }

  public void setComment(String comment) {
    this.comment = comment;
  }
}

==> rbac-import-2.2.1.44-Release-sources.jar: com/bizunited/platform/rbac/vo/RoleImportVo.java <==
package com.bizunited.platform.rbac.vo;

import com.bizunited.platform.kuiper.starter.common.excel.NebulaExcelColumn;
import com.bizunited.platform.kuiper.starter.common.excel.NebulaExcelImport;
import java.io.Serializable;

/**
 * 角色导入对象模型
 * @Author: chenrong
 * @Date: 2020/10/28 9:24
 */
@NebulaExcelImport(startRow = 2)
public class RoleImportVo implements Serializable {

  private static final long serialVersionUID = -8169850517983676178L;

  /** 角色编码 **/
  @NebulaExcelColumn(order = 0)
  private String roleCode;

  /** 角色名称 **/
  @NebulaExcelColumn(order = 1)
  private String roleName;

  /** 角色类型 **/
  @NebulaExcelColumn(order = 2)
  private String roleType;

  /** 角色状态 **/
  @NebulaExcelColumn(order = 3)
  private String statusDes;

  /** 是否系统角色 **/
  @NebulaExcelColumn(order = 4)
  private String denyDes;

  /** 父级角色编码 **/
  @NebulaExcelColumn(order = 5)
  private String parentCode;

  /** 角色备注 **/
  @NebulaExcelColumn(order = 6)
  private String comment;

  public String getRoleCode() {
    return roleCode;
  }

  public void setRoleCode(String roleCode) {
    this.roleCode = roleCode;
  }

  public String getRoleName() {
    return roleName;
  }

  public void setRoleName(String roleName) {
    this.roleName = roleName;
  }

  public String getRoleType() {
    return roleType;
  }

  public void setRoleType(String roleType) {
    this.roleType = roleType;
  }

  public String getStatusDes() {
    return statusDes;
  }

  public void setStatusDes(String statusDes) {
    this.statusDes = statusDes;
  }

  public String getDenyDes() {
    return denyDes;
  }

  public void setDenyDes(String denyDes) {
    this.denyDes = denyDes;
  }

  public String getParentCode() {
    return parentCode;
  }

  public void setParentCode(String parentCode) {
    this.parentCode = parentCode;
  }

  public String getComment() {
    return comment;
  }

  public void setComment(String comment) {
    this.comment = comment;
  }
}
